Contains functions providing finer control over OTP generation and verification parameters

Functions

Generates a one time password using the given secret, nonce, digits and algorithm.
Uses the provided algorithm, digit length and lookahead to generate lookahead + 1 passwords to compare with the given one.
Verifies the given password for the given timestamp and secret.

Type Definitions

SHA-1 hasher state.
SHA-256 hasher.
SHA-512 hasher.